@@ -17,13 +17,6 @@ DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
 FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 """
 
-###############################################################################
-#                                                                             #
-# Apr 2022                                                                    #
-# felix@kemeth.de                                                             #
-#                                                                             #
-###############################################################################
-
 from configparser import SectionProxy
 
 import findiff
@@ -35,10 +28,9 @@ class Network(torch.nn.Module):
     """
     Pytorch PDE neural network.
 
-    Arguments
-    -------
-    config                    - Config with hyperparameters
-    n_vars                    - Number of system variables
+    Args:
+        config: Config with hyperparameters
+        n_vars: Number of system variables
     """
 
     def __init__(self, config: SectionProxy, n_vars: int):
@@ -87,17 +79,16 @@ class Network(torch.nn.Module):
         """
         Get finite difference coefficients.
 
-        Arguments
-        -------
-        min_deriv           - Order of minimal derivative
-        max_deriv           - Order of maximal derivative
+        Args:
+            min_deriv: Order of minimal derivative
+            max_deriv: Order of maximal derivative
 
-        Returns
-        -------
-        Tensor with finite difference coefficients
+        Returns:
+            Tensor with finite difference coefficients
         """
-        assert max_deriv > min_deriv, 'Derivative range not specified'
-        assert min_deriv >= 0, 'Derivatives should be larger zero'
+        assert max_deriv > min_deriv, 'Max derivative should be larger than min derivative.'
+        assert min_deriv >= 0, 'Min derivative should be positive.'
+        assert max_deriv < self.kernel_size, 'Max derivative should not be larger than kernel size.'
 
         coeffs = np.zeros((max_deriv-min_deriv+1, 1, self.kernel_size))
         # Finite difference coefficients
@@ -122,15 +113,13 @@ class Network(torch.nn.Module):
         """
         Calculate derivativers of input snapshot.
 
-        Arguments
-        -------
-        input_tensor        - Tensor with input features
-        delta_x             - Tensor with spatial resolution
-        param               - Tensor with system parameters
+        Args:
+            input_tensor: Tensor with input features
+            delta_x: Tensor with spatial resolution
+            param: Tensor with system parameters
 
-        Returns
-        -------
-        Spatial derivative tensor
+        Returns:
+            Spatial derivative tensor
         """
         finite_diffs = torch.cat([
             torch.nn.functional.conv1d(
@@ -151,15 +140,13 @@ class Network(torch.nn.Module):
         """
         Forward pass through PDE neural network.
 
-        Arguments
-        -------
-        input_tensor        - Tensor with input features
-        delta_x             - Tensor with spatial resolution
-        param               - Tensor with system parameters
+        Args:
+            input_tensor: Tensor with input features
+            delta_x: Tensor with spatial resolution
+            param: Tensor with system parameters
 
-        Returns
-        -------
-        Output prediction tensor
+        Returns:
+            Output prediction tensor
         """
         # Calculate derivatives
         input_tensor = self.calc_derivs(input_tensor, delta_x)
